@@ -1,6 +1,6 @@
 from .page_template import page_layout
-from .css import get_css
 from .text2html import ArticleContent
+from .. import conf
 
 
 def generate_html(article):
@@ -10,6 +10,6 @@ def generate_html(article):
     :param article: Article object containing title and content as plain text
     """
     content = ArticleContent(article.content)
-    html =  page_layout(article.title, content, get_css())
+    html =  page_layout(article.title, content, conf.css)
     return html
 
